#!/usr/bin/env python
# GPLv2

from __future__ import print_function
import ConfigParser
import tscommon
import sys
import os

def cldemo(filename="start.txt"):
	while True:
		config = ConfigParser.RawConfigParser()
		config.read(tscommon.datadir + "/" + filename)
		print("")
		print(filename)
		print(config.get("Question", "Q"))
		if config.has_section("Options"):
			num = 0
			for opt in config.items("Options"):
				num += 1
				print(" ", num, opt[1])
			inp = int(raw_input("Select [1-"+str(num)+"]: ")) - 1
			filename = config.items("Options")[inp][0]
		else: return

# This is grossly inefficient.
def traverse(filename="start.txt", depth=0, stack=[], outputhtml=False):
	config = ConfigParser.RawConfigParser()
	if not os.path.exists(tscommon.datadir + "/" + filename):
		print("ERROR: File", filename, "does not exist")
		sys.exit(-1)
	config.read(tscommon.datadir + "/" + filename)
	print(config.get("Question", "Q"))
	if filename in stack:
		print("ERROR: Cycle Detected!")
		sys.exit(-1)
	stack.append(filename)
	if outputhtml:
		f = open(tscommon.htmldir+"/"+filename+".html", "w")
		tscommon.htmlpage(tscommon.datadir + "/" + filename, f)
	if config.has_section("Options"):
		for opt in config.items("Options"):
			print("  ", "  "*depth, opt[1], ": ", end="")
			traverse(opt[0], depth+1, stack, outputhtml)
	stack.pop()

def statichtml():
	tscommon.linkformat='<a href="{0}.html">'
	if os.path.exists(tscommon.htmldir):
		print("Error: directory '"+tscommon.htmldir+"' already exists. Remove it first.")
		return
	os.mkdir(tscommon.htmldir)
	traverse(outputhtml=True)

def verify():
	traverse()
	print("Success.")

def main():
	if len(sys.argv) > 1:
		if sys.argv[1] == "verify":
			return verify()
		elif sys.argv[1] == "html":
			return statichtml()
		elif sys.argv[1] == "cldemo":
			return cldemo()
	print("USAGE:", sys.argv[0], "[ verify | statichtml | cldemo ]")
	print("""
	verify:     run through all data files to check for errors
	html:       generate static html troubleshooter
	cldemo:     a rudimentary interactive command line troubleshooter
	""")

main()
